// import {Scene, Color, PerspectiveCamera, WebGLRenderer, PointLight} from 'https://unpkg.com/three@0.145.0/build/three.module.js';
import {Scene, Color, PerspectiveCamera, WebGLRenderer, PointLight} from './three.min.js';
import {OrbitControls} from 'https://unpkg.com/three@0.145.0/examples/jsm/controls/OrbitControls.js';
import OBJLoader from './OBJLoader';
import MTLLoader from './MTLLoader';

const renderer = new WebGLRenderer();
renderer.setSize(window.innerWidth, window.innerHeight);
document.getElementById('3d-section').appendChild(renderer.domElement);

const scene = new Scene();
scene.background = new Color(0xdddddd);

const camera = new PerspectiveCamera(45, window.innerWidth / window.innerHeight, 1, 2000);
camera.rotation.y = (45 / 180) * Math.PI;
camera.position.x = 800;
camera.position.y = 100;
camera.position.z = 1000;

const control = new OrbitControls(camera, renderer.domElement);
control.enableDamping = true;
control.campingFactor = 0.25;
control.enableZoom = true;

const light1 = new PointLight(0xc4c4c4, 1);
light1.position.set(0, 300, 300);
scene.add(light1)

const light2 = new PointLight(0xc4c4c4, 1);
light2.position.set(500, 100, 0);
scene.add(light2)

const light3 = new PointLight(0xc4c4c4, 1);
light3.position.set(0, 100, -500);
scene.add(light3)

const light4 = new PointLight(0xc4c4c4, 1);
light4.position.set(-500, 300, 500);
scene.add(light4)


const mtlLoader = new MTLLoader();
mtlLoader.load('https://assets.fallenstore.com.br/3d/assets/cactus.mtl', (materials) => {
  materials.preload();

  const objLoader = new OBJLoader();
  objLoader.setMaterials(materials);
  objLoader.load('https://assets.fallenstore.com.br/3d/assets/cactus.obj', (object) => {
    object.scale.set(20, 20, 20);
    scene.add(object);
  }, (xhr) => {
    console.log(`Carregando obj: ${(xhr.loaded / xhr.total) * 100}%`);

  }, (err) => {
    console.log(`Erro: ${err}`);
  }
);
}, (xhr) => {
  console.log(`Carregando material: ${(xhr.loaded / xhr.total) * 100}%`)
}, (err) => {
  console.log(`Erro: ${err}`)
});

const animate = function animate() {
  requestAnimationFrame(animate);

  control.update();

  renderer.render(scene, camera);
}

animate();